OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "Não foi possível excluir %s permanentemente",
    "Couldn't restore %s" : "Não foi possível restaurar %s",
    "Deleted files" : "Arquivos apagados",
    "Restore" : "Restaurar",
    "Delete" : "Excluir",
    "Delete permanently" : "Excluir permanentemente",
    "Error" : "Erro",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor, verifique os logs ou entre em contato com o administrador",
    "restored" : "restaurado",
    "No deleted files" : "Nenhum arquivo excluído",
    "You will be able to recover deleted files from here" : "Neste local, você será capaz de recuperar arquivos excluídos",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Select all" : "Selecionar tudo",
    "Name" : "Nome",
    "Deleted" : "Excluído"
},
"nplurals=2; plural=(n > 1);");
